======
HiWord
======

.. image:: https://img.shields.io/badge/license-Apache 2-blue.svg
    :target: https://github.com/jadbin/hiword/blob/master/LICENSE

Overview
========

HiWord is used to extract keywords from documents.

Installation
============

Install or update using pip::

    $ pip install -U hiword

